#
# spec file for package libxklavier
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           libxklavier
Version:        5.4
Release:        2.2
Summary:        Library with X keyboard related functions
License:        LGPL-2.0-or-later
Group:          Development/Libraries/X11
URL:            http://www.freedesktop.org/Software/LibXklavier
#Source:         http://download.gnome.org/sources/libxklavier/5.4/%%{name}-%%{version}.tar.xz
Source:         http://people.freedesktop.org/~svu/libxklavier-5.4.tar.bz2

BuildRequires:  doxygen
BuildRequires:  gobject-introspection-devel >= 1.30
BuildRequires:  gtk-doc
BuildRequires:  iso-codes-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xi)
BuildRequires:  pkgconfig(xkbfile)
Requires:       xkbcomp

%description
This library allows you to simplify XKB-related development.

%package devel
Summary:        Development files for libxklavier
Group:          Development/Libraries/X11
Requires:       %{name} = %{version}
Requires:       glibc-devel
Requires:       libxklavier16 = %{version}
Requires:       typelib-1_0-Xkl-1_0 = %{version}

%description devel
This package contains all necessary include files and libraries needed
to develop applications that require these.

%package -n libxklavier16
Summary:        Library with X keyboard related functions
Group:          System/Libraries
Requires:       iso-codes
Provides:       %{name} = %{version}
Obsoletes:      %{name} < %{version}

%description -n libxklavier16
This library allows you to simplify XKB-related development.

%package -n typelib-1_0-Xkl-1_0
Summary:        Introspection bindings for libxklavier
Group:          System/Libraries

%description -n typelib-1_0-Xkl-1_0
This library allows you to simplify XKB-related development.

This package provides the GObject Introspection bindings for
libxklavier.

%package doc
Summary:        Additional Package Documentation for libxklavier
Group:          Documentation/HTML
Requires:       %{name} = %{version}

%description doc
This library allows you to simplify XKB-related development.

%prep
%autosetup -p1

%build
%configure \
	--with-xkb-base=%{_datadir}/X11/xkb \
	--with-xkb-bin-base=%{_bindir} \
	--disable-static \
	%{nil}
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%ldconfig_scriptlets -n libxklavier16

%files -n libxklavier16
%license COPYING.LIB
%doc AUTHORS CREDITS ChangeLog NEWS README
%{_libdir}/libxklavier.so.*

%files -n typelib-1_0-Xkl-1_0
%{_libdir}/girepository-1.0/Xkl-1.0.typelib

%files devel
%{_includedir}/libxklavier/
%{_libdir}/libxklavier.so
%{_libdir}/pkgconfig/libxklavier.pc
%{_datadir}/gir-1.0/Xkl-1.0.gir

%files doc
%{_datadir}/gtk-doc/html/libxklavier

%changelog
* Tue Mar  5 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Drop baselibs.conf: the -32bit packages are no longer needed and
  have not been part of Tumbleweed for a while already (build for
  i586 only enabled in LegacyX86).
* Sun Mar  6 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 5.4:
  + A couple of introspection fixes.
- Update URL, this version was never released on download.gnome.org
- Add explicit libxklavier16 (shared library) Requires in devel
  sub-package (we already pulled it in via virtual provides).
- Use modern macros.
* Mon Mar  5 2018 jengelh@inai.de
- Fix RPM groups. Update summaries. Remove --with-pic.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Mon Feb  1 2016 dimstar@opensuse.org
- Pass --with-xkb-bin-base=%%{_bindir} to configure: we know that
  xkbcomp is installed there (boo#964360).
- Add xkbcomp Requires to libxklavier16: the xkbcomp binary is
  required for proper functioning of the library.
* Sat Oct 18 2014 crrodriguez@opensuse.org
- Discontinue the use of xorg-x11-devel metapackage, just
  buildrequire pkgconfig(xi), pkgconfig(x11), pkgconfig(xkbfile).
* Mon Sep 24 2012 dimstar@opensuse.org
- Update to version 5.3:
  +  A number of introspection and build fixes.
* Thu Feb 16 2012 dimstar@opensuse.org
- Update to version 5.2.1:
  + Fixed GIR params for introspection (broken build)
- Remove xz BuildRequires now that it comes for free in the build
  system.
- Drop libxklavier-fix-gir-build.patch: fixed upstream.
- Change glib2-devel and libxml2-devel BuildRequires to their
  pkgconfig() equivalents: glib-2.0 and libxml-2.0.
- Clean spec file using spec-cleaner.
* Thu Jan 26 2012 vuntz@opensuse.org
- license update: LGPL-2.0+
  No indication of GPL-2.0+ tools or utilities (apart from
  configure, etc.)
* Wed Jan 18 2012 vuntz@opensuse.org
- Update to version 5.2:
  + Optional introspection introduced
  + Some minor fixes (runtime and build-time)
- Add xz BuildRequires because we can't build a package for a
  xz-compressed tarball without explicitly specifying that... See
  bnc#697467 for more details.
- Add gobject-introspection-devel BuildRequires to build
  introspection support.
- Add libxklavier-fix-gir-build.patch to fix build of introspection
  support.
- Create typelib-1_0-Xkl-1_0 subpackage for typelib file.
- Add typelib-1_0-Xkl-1_0 Requires to devel subpackage.
- Remove glib2-devel and libxml2-devel Requires from devel
  subpackage: they will automatically be added the pkgconfig() way.
- Remove Requires for the XFree86-devel provider from devel
  subpackage: it's not needed according to the pkgconfig file.
- Change group of libxklavier16 from Development/Libraries/X11 to
  System/Libraries.
* Thu Oct  6 2011 vuntz@opensuse.org
- Add iso-codes Requires to libxklavier16 since the iso-codes data
  is used at runtime.
* Tue Apr 19 2011 ro@suse.de
- Update baselibs.conf (libxklavier16 instead of libxklavier12)
* Mon Feb 14 2011 fcrozat@novell.com
- Update to version 5.1:
  + Expanding APIs for GNOME 3 needs:
  - converting ISO codes to translatable names (it was private,
    now public)
  - search by pattern
  + Using X11 API through pkg-config
  + One race condition eliminated
  + XInput2 version checking: looking for support of DevicePresence
* Wed Jan 13 2010 captain.magnus@opensuse.org
- Update to version 5.0:
  + Introducing counters for start/stop listen operations: in one
    process (actually g-s-d) start and stop can be called several
    times, with different masks. The API is incompatibly changed!
  + Using transient property for smart handling of the popup
    windows (for the per-window layout scenario)
  + Save xinput error code and event type
  + Introduced engine-specific error handling (for ignoring xinput
    errors)
  + Sometimes focus_in arrives when the previously focused window
    is already destroyed. That causes BadMatch and all kinds of
    trouble. The code should handle that case correctly
  + Fixed a bug with XIE check (bgo#583709)
  + Small fix for flag enum fdo#21578
- Rename libxklavier15 subpackage to libxklavier16, following
  soname change.
* Tue Jan  5 2010 jengelh@medozas.de
- Package baselibs.conf
* Sun Aug  2 2009 coolo@novell.com
- remove the obsolete to the old library, shared libraries are supposed
  to be installable in parallel
* Mon Jul 20 2009 vuntz@novell.com
- Update to version 4.0:
  + Support for "extras" in xkeyboard-config, small bugfixes and
    build fixes.
- Rename libxklavier12 to libxklavier15 and make it Obsolete
  libxklavier12.
* Thu Mar 19 2009 vuntz@novell.com
- Update to version 3.9:
  + Several small bugs fixed, including memleak and crash under NX
- Remove AutoReqProv: it's default now.
- Use makeinstall.
- Remove libxklavier package (contained only doc) and have
  libxklavier12 provide it.
- Remove work-around for old versions of openSUSE and autoreconf
  call.
* Mon Jan 26 2009 crrodriguez@suse.de
- remove "la" files [BNC#357465]
* Wed Dec 24 2008 mboman@suse.de
- Update to version 3.8:
  + Added "new device" signal - for plugged keyboard
* Wed Sep 10 2008 maw@suse.de
- Update to version 3.7:
  + Several bugfixes
  + Convert all translated strings to UTF-8.
* Fri Jun 20 2008 maw@suse.de
- Update to version 3.6:
  + Added API for countries and languages.
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Thu Apr  3 2008 hpj@suse.de
- Upgrade to version 3.5:
  * Got rid of the fallback xml file (some code cleanup).
  * Fixed a couple of bugs (one crasher).
* Sun Feb 10 2008 coolo@suse.de
- don't make the library unreadable
* Tue Feb  5 2008 maw@suse.de
- Split out a shared library subpackage.
* Thu Jan 31 2008 rodrigo@suse.de
- Update to version 3.4:
  * Use gettext for translations
- Fixed package summaries to pass rpmlint checks
* Fri Jan 25 2008 rodrigo@suse.de
- Update to version 3.3:
  * Support of the "vendor" tag in base.xml
  * Minor bugfixes
- Removed COPYING from %%doc, it now includes COPYING.LIB
* Fri Jul  6 2007 maw@suse.de
- Update to version 3.2
- Bugfixes
- Remove upstreamed libxklavier-216201-kbd-layout-fix.patch.
* Mon Mar  5 2007 danw@suse.de
- Add back --with-xkb-base that got removed in the spec file
  cleanup. #250556
* Tue Feb 13 2007 sbrabec@suse.cz
- Do not build unusable static libraries (#238552#c17).
* Tue Dec 19 2006 sbrabec@suse.cz
- Spec file cleanup.
* Thu Nov 16 2006 danw@suse.de
- Add patch from CVS to fix a crash in the keyboard layout indicator
  [#216201]
* Fri Oct 13 2006 danw@suse.de
- Remove dead patch (fixed differently upstream)
* Wed Oct 11 2006 danw@suse.de
- Fix xkb-base to match xkeyboard-config package. #204368, etc
- Remove some disabled patches that have been committed upstream
* Wed Aug 30 2006 jhargadon@suse.de
- update to version 3.0
- Some fixes in 2.91. Huge memory optimization
* Tue Aug 22 2006 aj@suse.de
- Remove unneeded BuildRequires.
* Fri Aug 18 2006 jhargadon@suse.de
- update to version 2.91
- Absolutely new API based on glib
- Bugfixes
- XML processing improved
- Better compatibility with modular X.org filesystem layout
* Thu Jul 20 2006 danw@suse.de
- Use AC_PATH_XTRA rather than AC_PATH_X to make it easier to deal
  correctly with xorg-modular (which installs into /usr and so
  doesn't require -I or -L flags)
* Fri Jun  9 2006 danw@suse.de
- Fix two weird NULL->int casts with a patch from libxklavier HEAD
  to fix the beta build.
* Thu Mar 23 2006 danw@suse.de
- trap X errors when setting the keyboard map, to protect against
  bad data from callers or other packages (eg, xkeyboard-config, which
  currently seems to have a bug). Part of #158177
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Jan 17 2006 sbrabec@suse.cz
- Updared to version 2.1.
* Wed Dec  7 2005 rodrigo@suse.de
- Added unreleased patch libxklavier-waitpid.patch, needed for
  control-center2-2.12.2.
* Wed Nov  2 2005 dmueller@suse.de
- don't build as root
* Wed Jun  1 2005 sbrabec@suse.cz
- Fixed devel requirements.
* Tue Apr 26 2005 gekker@suse.de
- Disable -Werror for now.
* Wed Mar  9 2005 gekker@suse.de
- Update to version 2.0 (GNOME 2.10).
* Fri Jan 21 2005 gekker@suse.de
- Update to version 1.14
- Remove patch, already upstream
* Wed Dec 22 2004 ro@suse.de
- added missing includes to test_config.c
* Tue Dec 21 2004 gekker@suse.de
- Update to version 1.04
* Thu Aug 12 2004 ro@suse.de
- added libpng to neededforbuild (for doxygen)
* Wed May 12 2004 clahey@suse.de
- Add --with-xkb-base=/usr/lib/X11/xkb to configure to make this
  build on 64 bit platforms.
* Fri Apr 30 2004 clahey@suse.de
- Upgraded to version 1.02 as needed for control-center.
* Mon Feb 16 2004 sbrabec@suse.cz
- Degraded to version 0.96 (GSwitchIt compatible with version 0.97 is
  not yet released).
* Thu Feb 12 2004 sbrabec@suse.cz
- Updated to version 0.97.
* Thu Sep  4 2003 ro@suse.de
- run autoreconf
- use configure to detect X11R6 libdir
* Thu Sep  4 2003 sbrabec@suse.cz
- Added new package (bug #28623).
